Crate subspedia_rs[−][src]
This crate is a simple library for subspedia based on api the provided by site
Structs
| ReqElencoSerie |
Struct to perform the request for the all series available on site. |
| ReqSerieTraduzione |
Struct to perform the request for the series that are in translation. |
| ReqSottotitoliSerie |
Struct to perform the subtitle request for a series. |
| ReqUltimiSottotitoli |
Struct to perform the request for the last subtitles translated. |
| Serie |
Struct for store the television series available on site. |
| SerieTraduzione |
Struct for store the television series in translation. |
| Sottotitolo |
Struct for store the subtitles. |
Enums
| FetchError |
An enumeration of possible error which can occur during http requests and the parsing of json returned by the api |
Traits
| Request |
Trait that requests have to implement. |
Functions
| get |
Makes a request based on given type |